/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.httpclient;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;

import org.zhiqim.kernel.util.Streams;

/**
 * HTTP/HTTPS GET访问类，把HttpURLConnection的流转化成ByteArrayInputStream，该类为非文本响应内容时使用
 *
 * @see HttpDownload 大文件下载，请使用HttpDownload替换，以防止内存使用过大
 * @version v1.0.0 @author zouzhigang 2014-3-21 新建与整理
 */
public class HttpGetStream extends HttpClient
{
    private ByteArrayOutputStream in;
    
    public HttpGetStream(String url)
    {
        super(url, _GET_);
    }
    
    /** 重写获取HTTP结果 */
    public HttpResult getResult()
    {
        return new HttpResult(responseStatus, responseText, in==null?null:in.toByteArray());
    }
    
    /** 获取输入流 */
    public InputStream getInputStream()
    {
        return new ByteArrayInputStream(in.toByteArray());
    }
    
    /** 获取字节数组 */
    public byte[] getBytes()
    {
        return in.toByteArray();
    }
    
    protected void doReadResponseContent(HttpURLConnection conn) throws IOException
    {
        if (responseStatus == _302_FOUND_)
        {//重定向
            responseText = conn.getHeaderField("Location");
            return;
        }
        
        if (responseStatus != _200_OK_)
        {//错误
            responseText = getResponseError(conn);
            return;
        }
        
        //成功
        in = new ByteArrayOutputStream();
        try(InputStream input = conn.getInputStream())
        {
            Streams.putBytes(input, in);
        }
        
        responseText = "调用成功";
    }
}
