/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.httpclient;

import java.io.IOException;
import java.net.HttpURLConnection;

import org.zhiqim.kernel.util.Bytes;
import org.zhiqim.kernel.util.Stringx;
import org.zhiqim.kernel.util.Validates;

/**
 * HTTP/HTTPS POST访问类
 * 1.内容以字符串为主，在写入时根据编码格式转换成字节
 * 2.当内容不为空时，必须有mimeType和encoding值
 *
 * @version v1.0.0 @author zouzhigang 2014-3-21 新建与整理
 */
public class HttpPost extends HttpClient
{
    private String queryString;
    private String mimeType;
    private String encoding;
    
    public HttpPost(String url)
    {
        super(url, _POST_);
        
        this.mimeType = _APPLICATION_X_WWW_FORM_;
        this.encoding = _UTF_8_;
    }
    
    public HttpPost setQueryString(String queryString)
    {
        this.queryString = Stringx.trim(queryString);
        return this;
    }
    
    public HttpPost setQueryString(String queryString, String encoding)
    {
        this.queryString = Stringx.trim(queryString);
        this.encoding = Stringx.trim(encoding);
        return this;
    }
    
    public HttpPost setQueryString(String queryString, String mimeType, String encoding)
    {
        this.queryString = Stringx.trim(queryString);
        this.mimeType = Stringx.trim(mimeType);
        this.encoding = Stringx.trim(encoding);
        return this;
    }
    
    protected boolean doPreRequestProperty()
    {//默认需要打开输出流
        setDoOutput(true);
        if (!hasRequestProperty(_CONTENT_TYPE_))
        {//没有设置ContentType的才设置
            setRequestProperty(_CONTENT_TYPE_, mimeType + "; charset="+encoding);
        }
        setRequestProperty(_CONTENT_LENGTH_, Bytes.getByteLen(queryString, encoding));
        return true;
    }
    
    protected void doWriteRequestContent(HttpURLConnection conn) throws IOException
    {
        if (Validates.isEmpty(queryString))
        {//内容为空输出空字节数组
            conn.getOutputStream().write(new byte[0]);
        }
        else
        {//正常内容
            conn.getOutputStream().write(queryString.getBytes(encoding));
        }
    }
}
