/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.json.parser;

import java.util.List;
import java.util.Map.Entry;

import org.zhiqim.kernel.json.Json;
import org.zhiqim.kernel.json.JsonParser;
import org.zhiqim.kernel.json.Jsons;
import org.zhiqim.kernel.model.maps.MapSO;
import org.zhiqim.kernel.util.Classes;
import org.zhiqim.kernel.util.Validates;

/**
 * MapSO解析器
 *
 * @version v1.0.0 @author zouzhigang 2014-3-21 新建与整理
 */
public class MapSOParser implements JsonParser
{
    private Json jsonMain;
    
    public MapSOParser(Json jsonMain)
    {
        this.jsonMain = jsonMain;
    }
    
    @Override
    public String toString(Object obj)
    {
        MapSO map = (MapSO)obj;
        if (map.isEmpty())
            return "{}";
        
        StringBuilder strb = new StringBuilder("{");
        for (Entry<String, Object> entry : map.entrySet())
        {
            String key = entry.getKey();
            Object value = entry.getValue();
            strb.append("\"").append(key).append("\":").append(jsonMain.toString(value)).append(",");
        }
        
        strb.setLength(strb.length() - 1);
        strb.append("}");
        return strb.toString();
    }

    @Override
    public Object toObject(String json, Class<?> cls)
    {
        MapSO map = Classes.newMapSO(cls);
        if (map == null)
        {//不支持的类型
            return null;
        }
        
        List<String> list = Jsons.toListByObject(json);
        for (String s : list)
        {
            int ind = s.indexOf(":");
            String key = Jsons.removeStartEndQuotation(s.substring(0, ind));
            String value = s.substring(ind+1);
            
            if ("null".equals(value))
            {//对null进行判断
                map.put(key, null);
                continue;
            }
            
            if (Jsons.isStartEndQuotation(value))
            {//是字符串
                map.put(key, Jsons.removeEscapeChar(Jsons.removeStartEndQuotation(value)));
                continue;
            }
            
            //基本类型、数组或对象
            if (Validates.isInteger(value))//数值统一转为long，以便强制转化
                map.put(key, Long.parseLong(value));
            else if (Validates.isFloat(value))//浮点统一转为double，以便强制转化
                map.put(key, Double.parseDouble(value));
            else if ("true".equalsIgnoreCase(value))
                map.put(key, true);
            else if ("false".equalsIgnoreCase(value))
                map.put(key, false);
            else
                map.put(key, value);
        }
        
        return map;
    }
}
