/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.logging;

import org.zhiqim.kernel.Z;
import org.zhiqim.kernel.config.Group;
import org.zhiqim.kernel.service.Servicer;

/**
 * 适配其他日志服务器，调用其他打印日志服务日志
 *
 * @version v1.0.0 @author zouzhigang 2014-2-27 新建与整理
 */
public class LogServerAdapter extends Servicer implements LogService
{
    private Logger logger = null;
    
    @Override
    public boolean create() throws Exception
    {
        Group group = Z.conf().group(id);
        
        //先检查日志工厂方法
        String adapter = group.getString("adapter");
        if (adapter == null)
        {
            System.out.println("未配置日志适配器");
            return false;
        }
        
        Object obj = Z.cls().newInstance(adapter);
        if (obj == null || !(obj instanceof Logger))
        {
            System.out.println("配置的日志适配器无法初始化或没有继承自Logger类");
            return false;
        }
        
        //转换为日志输出器，调用加载方法
        logger = (Logger)obj;
        if (!logger.load())
        {
            System.out.println("配置的日志适配器适配失败");
            return false;
        }
        
        //更新日志工厂为适配器提供服务
        LogFactory.updateLogService(this);
        return true;
    }
    
    @Override
    public Logger getLogger(Log log, int level)
    {
        return logger;
    }

    @Override
    public boolean isEnabled(Log log, int level)
    {
        return logger.isEnabled(log, level);
    }
}
