/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.model.maps;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.zhiqim.kernel.annotation.AnAlias;
import org.zhiqim.kernel.annotation.AnNew;

/**
 * 定义一个HashMap<Class<?>, V>参数和结果对象
 *
 * @version v1.0.0 @author zouzhigang 2016-10-25 新建与整理
 */
@AnAlias("HashMapCV")
@AnNew
public class HashMapCV<V> extends MapCV<V>
{
    /****************************************************************************************************/
    //HashMap
    /****************************************************************************************************/
    
    public HashMapCV()
    {
        this(false);
    }
    
    public HashMapCV(int count)
    {
        this(count, false);
    }
    
    public HashMapCV(Class<?> key, V value)
    {
        this(key, value, false);
    }
    
    public HashMapCV(Map<Class<?>, V> instance)
    {
        this(instance, false);
    }
    
    public HashMapCV(MapCV<V> map)
    {
        this(map, false);
    }
    
    /****************************************************************************************************/
    //ConcurrentHashMap
    /****************************************************************************************************/
    

    public HashMapCV(boolean concurrent)
    {
        if (concurrent)
            instance = new ConcurrentHashMap<>();
        else
            instance = new HashMap<>();
    }
    
    public HashMapCV(int count, boolean concurrent)
    {
        if (concurrent)
            instance = new ConcurrentHashMap<>(count);
        else
            instance = new HashMap<>(count);
    }
    
    public HashMapCV(Class<?> key, V value, boolean concurrent)
    {
        this(concurrent);
        instance.put(key, value);
    }
    
    public HashMapCV(Map<Class<?>, V> instance, boolean concurrent)
    {
        if (concurrent)
            instance = new ConcurrentHashMap<>(instance);
        else
            instance = new HashMap<>(instance);
    }
    
    public HashMapCV(MapCV<V> map, boolean concurrent)
    {
        this(map.instance(), concurrent);
    }
}
