/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.model.maps;

import java.util.Collection;
import java.util.Map;
import java.util.Set;

/**
 * 定义在特定场景创建Map<String, Class<?>>时，无需指定泛型
 *
 * @version v1.0.0 @author zouzhigang 2016-11-15 新建与整理
 */
public abstract class MapSC implements MapS
{
    protected Map<String, Class<?>> instance;
    
    /***********************************************************/
    //返回Map实例的方法
    /***********************************************************/
    
    /**
     * 返回对应的Map实例
     * 
     * @return          Map实例
     */
    public Map<String, Class<?>> instance()
    {
        return instance;
    }
    
    /***********************************************************/
    //增加&修改&删除Map数据
    /***********************************************************/
    
    /**
     * 从原来的MapSC中放置所有的元素到当前MapSC
     * 
     * @param m         原有MapSC
     * @return          返回自身
     */
    public MapSC putAll(MapSC m)
    {
        instance.putAll(m.instance());
        return this;
    }
    
    public MapSC putAll(Map<String, Class<?>> m)
    {
        instance.putAll(m);
        return this;
    }

    public MapSC put(String key, Class<?> value)
    {
        instance.put(key, value);
        return this;
    }
    
    public MapSC clear()
    {
        instance.clear();
        return this;
    }
    
    /***********************************************************/
    //获取Map的数据
    /***********************************************************/
    
    public Class<?> get(String key)
    {
        return instance.get(key);
    }
    
    public Class<?> remove(String key)
    {
        return instance.remove(key);
    }
    
    public int size()
    {
        return instance.size();
    }
    
    public boolean isEmpty()
    {
        return instance.isEmpty();
    }
    
    public boolean containsKey(String key)
    {
        return instance.containsKey(key);
    }
    
    public boolean containsValue(Class<?> value)
    {
        return instance.containsValue(value);
    }
    
    public Set<String> keySet()
    {
        return instance.keySet();
    }
    
    public Collection<Class<?>> values()
    {
        return instance.values();
    }
    
    public Set<Map.Entry<String, Class<?>>> entrySet()
    {
        return instance.entrySet();
    }
    
    public String toString()
    {
        return instance.toString();
    }
}
