/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.model.objects;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.zhiqim.kernel.annotation.AnAlias;
import org.zhiqim.kernel.annotation.AnNew;
import org.zhiqim.kernel.json.Jsons;

/**
 * 定义一个ArrayList<String>对象，在ZML中new时不需要指定泛型
 *
 * @version v1.0.0 @author zouzhigang 2016-10-25 新建与整理
 */
@AnAlias("SList")
@AnNew
public class SList implements Iterable<String>
{
    private final ArrayList<String> instance;
    
    public SList()
    {
        instance = new ArrayList<>();
    }
    
    public SList(int count)
    {
        instance = new ArrayList<>(count);
    }
    
    public SList(String s)
    {
        instance = new ArrayList<>(1);
        instance.add(s);
    }
    
    public SList(Collection<String> instance)
    {
        this.instance = new ArrayList<>(instance);
    }
    
    public SList(SList instance)
    {
        this.instance = new ArrayList<>(instance.instance());
    }
    
    /***********************************************************/
    //实例化
    /***********************************************************/
    
    /**
     * 返回对应的List实例
     * 
     * @return          List实例
     */
    public ArrayList<String> instance()
    {
        return instance;
    }
    
    /***********************************************************/
    //私有方法
    /***********************************************************/
    
    public SList trimToSize() 
    {
        instance.trimToSize();
        return this;
    }
    
    @Override
    public String toString()
    {
        return Jsons.toString(instance);
    }

    @Override
    public Iterator<String> iterator()
    {
        return instance.iterator();
    }
    
    public void clear() 
    {
        instance().clear();
    }
    
    public String get(int index) 
    {
        return instance().get(index);
    }

    public String[] toArray() 
    {
        return instance().toArray(new String[0]);
    }
    
    public boolean add(String e) 
    {
        return instance().add(e);
    }

    public boolean remove(String o) 
    {
        return instance().remove(o);
    }

    public String remove(int index) 
    {
        return instance().remove(index);
    }

    public int indexOf(String o) 
    {
        return instance().indexOf(o);
    }
}
