/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.model.results;

/**
 * 异常结果对象
 *
 * @version v1.0.0 @author zgzou 2021年11月23日 新建与整理
 */
public class RE<T> extends R<T>
{
    private Throwable exception;
    
    @Override /** 是否成功 */
    public boolean success()
    {
        return exception == null;
    }

    @Override /** 安全检查 */
    protected void check()
    {
        throw new RuntimeException(exception);
    }
    
    /************************************************************************/
    //静态方法创建对象
    /************************************************************************/
    
    /** 静态方法创建对象并初始化正确值 */
    public static <T> RE<T> value(T value)
    {
        RE<T> r = new RE<T>();
        r.value = value;
        return r;
    }
    
    /** 静态方法创建对象并初始化无内容的正确值 */
    public static <T> RE<T> none()
    {
        return new RE<T>();
    }
    
    /** 静态方法创建对象并初始化异常信息 */
    public static <T> RE<T> message(String message)
    {
        RE<T> r = new RE<T>();
        r.exception = new Throwable(message);
        return r;
    }
    
    /** 静态方法创建对象并初始化异常 */
    public static <T> RE<T> exception(Throwable exception)
    {
        RE<T> r = new RE<T>();
        r.exception = exception;
        return r;
    }
    
    /************************************************************************/
    //获取值
    /************************************************************************/
    
    public String message()
    {
        return exception.getMessage();
    }
    
    public Throwable exception()
    {
        return exception;
    }
}
