/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.model.results;

/**
 * 整型code/msg结果对象
 *
 * @version v1.0.0 @author zgzou 2021年11月23日 新建与整理
 */
public class RIS<T> extends R<T>
{
    private int errCode;
    private String errMsg;
    
    @Override /** 是否成功 */
    public boolean success()
    {
        return errCode == 0;
    }

    @Override /** 安全检查 */
    protected void check()
    {
        throw new RuntimeException("errCode:"+errCode+",errMsg:"+errMsg);
    }
    
    /************************************************************************/
    //静态方法创建对象
    /************************************************************************/
    
    /** 静态方法创建对象并初始化正确值 */
    public static <T> RIS<T> value(T value)
    {
        RIS<T> r = new RIS<>();
        r.value = value;
        return r;
    }
    
    /** 静态方法创建对象并初始化无内容的正确值 */
    public static <T> RIS<T> none()
    {
        return new RIS<T>();
    }
    
    /** 静态方法创建对象并初始化错误码 */
    public static <T> RIS<T> error(int code, String msg)
    {
        RIS<T> r = new RIS<>();
        r.errCode = code;
        r.errMsg = msg;
        return r;
    }
    
    /************************************************************************/
    //获取值
    /************************************************************************/
    
    public T value()
    {
        return value;
    }
    
    public int errCode()
    {
        return errCode;
    }
    
    public String errMsg()
    {
        return errMsg;
    }
    
    public String errMsg(int len)
    {
        return errMsg == null?null:(errMsg.length()>len?errMsg.substring(0, len):errMsg);
    }
}
