/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.schedule;

import org.zhiqim.kernel.annotation.AnAlias;
import org.zhiqim.kernel.util.DateTimes;

/**
 * 每分钟任务，设置秒后在该点运行
 * 时间格式：yyyyMMddHHmm
 *
 * @version v1.0.0 @author zouzhigang 2014-2-27 新建与整理
 */
@AnAlias("Minute")
public final class Minute extends TaskThreader
{
    private int taskSecond  = 0;                //指定处理的秒
    
    /** 空构造函数,用于newInstance后再设置参数 */
    public Minute(){}
    
    /**
     * 设置定时安排时间点，指定每日的时该任务运行
     * 
     * @param task      任务
     * @param second    指定秒
     */
    public Minute(Task task, int second)
    {
        schedule(task, new int[]{second});
    }
    
    @Override /** 任务名称 */
    public String getName()
    {
        return "Minute";
    }
    
    @Override /** 任务时间 */
    public String getTime()
    {
        return new StringBuilder().append(taskSecond).toString();
    }
    
    @Override /** 时钟安排 */
    protected TaskThreader schedule(Task task, int[] time)
    {
        if (task == null || time == null || time.length != 1)
            throw new RuntimeException("Minute传入的参数为空或数组长度不对");
        
        if (time[0] < 0 || time[0] > 59)
            throw new RuntimeException("Minute传时的时间格式不正确");
        
        super.task = task;
        this.taskSecond = time[0];
        return this;
    }

    @Override /** 计算上次执行时刻 */
    protected long calcLastTime(int curYearMonth, int curMonthMaxDay, int curDay, int curHour, int curMinute, int curSecond, int curWeek)
    {
        return curYearMonth * 1000000L + curDay * 10000 + curHour * 100 + curMinute;
    }
    
    @Override /** 计算上次执行时刻的下一个时刻 */
    protected long calcLastTimeNextTime()
    {
        return DateTimes.getNextMinute(lastTime);
    }
    
    @Override /** 验证时间是否到达 */
    protected final boolean isArrive(int curYearMonth, int curMonthMaxDay, int curDay, int curHour, int curMinute, int curSecond, int curWeek)
    {
        //当前分钟，比较秒数
        return curSecond >= taskSecond;
    }
    
    public int getTaskSecond()
    {
        return taskSecond;
    }
    
    @Override
    public String toString()
    {
        return new StringBuilder("{type:Minute, ")
            .append("time:").append(taskSecond).append(", ")
            .append("first:").append(isFirstExecute).append("}")
            .toString();
    }
}
