/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.transaction;

import org.zhiqim.kernel.util.Arrays;

/**
 * 事务抽象类定义，包括提交、回滚和关闭状态
 *
 * @version v1.0.0 @author zouzhigang 2014-3-21 新建与整理
 */
public abstract class TransactionAbstracter implements Transaction
{
    protected String id;
    protected boolean isCommited = false;
    protected boolean isRollbacked = false;
    protected boolean isClosed = false;
    
    /** 要求提供id或id数组字符串，用于关闭 */
    public TransactionAbstracter(String id)
    {
        this.id = id;
    }
    
    /** 设置事务为已提交状态 */
    public void setCommitted()
    {
        isCommited = true;
        isRollbacked = false;
    }
    
    /** 设置事务为已回滚状态 */
    public void setRollbacked()
    {
        isCommited = false;
        isRollbacked = true;
    }
    
    /** 设置事务为已关闭状态 */
    public void setClosed()
    {
        isClosed = true;
        TransactionManager.closeTransaction(Arrays.toStringArray(id));
    }
    
    /** 获取事务服务编号 */
    public String getId()
    {
        return id;
    }
    
    /** 是否已提交 */
    public boolean isCommitted()
    {
        return isCommited;
    }
    
    /** 是否已回滚 */
    public boolean isRollbacked()
    {
        return isRollbacked;
    }
    
    /** 是否已关闭 */
    public boolean isClosed()
    {
        return isClosed;
    }
}
