/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.util;

import java.math.BigDecimal;

import org.zhiqim.kernel.annotation.AnAlias;
import org.zhiqim.kernel.constants.SignConstants;

/**
 * 小数计算
 *
 * @version v8.0.1 @author zouzhigang 2021年8月31日 新建与整理
 */
@AnAlias("Decimals")
public class Decimals implements SignConstants
{
    /** 格式化为保留4位小数 */
    public static String format(String val, int radixLen)
    {
        if (Validates.isEmptyBlank(val))
            return _EMPTY_;
        
        return new BigDecimal(val)
                  .setScale(radixLen, BigDecimal.ROUND_FLOOR)
                  .stripTrailingZeros()
                  .toPlainString();
    }
    
    
    /** 转化为百分比，即*100保留两位小数，四舍五入 */
    public static String precent(String val, int radixLen)
    {
        if (Validates.isEmptyBlank(val))
            return "0";
        
        return new BigDecimal(val).multiply(new BigDecimal("100"))
                   .setScale(radixLen, BigDecimal.ROUND_HALF_UP)
                   .stripTrailingZeros()
                   .toPlainString();
    }

    /** 相乘保留两位小数 */
    public static String multiply(String val1, String val2, int radixLen)
    {
        if (Validates.isEmptyBlank(val1) || Validates.isEmptyBlank(val2))
            return _EMPTY_;
        
        BigDecimal v1 = new BigDecimal(val1);
        BigDecimal v2 = new BigDecimal(val2);
        
        return v1.multiply(v2)
                 .setScale(radixLen, BigDecimal.ROUND_FLOOR)
                 .stripTrailingZeros()
                 .toPlainString();
    }

    /** 是否整除 */
    public static boolean isDivisible(String val1, String val2) 
    {
        Asserts.as((Validates.isFloat(val1) && Validates.isFloat(val2))?null:"参数都必须是整数或小数");
        
        BigDecimal v1 = new BigDecimal(val1);
        BigDecimal v2 = new BigDecimal(val2);
        
        BigDecimal val = v1.divide(v2, 3, BigDecimal.ROUND_HALF_UP);
        return val.stripTrailingZeros().scale() <= 0;
    }
    
    /** 通过小数精度，获取小数值 */
    public static String unit(int precision)
    {
        if (precision <= 0)
            return "1";
        
        StringBuilder strb = new StringBuilder("0.");
        for (int i=1;i<precision;i++)
            strb.append("0");
        strb.append("1");
        return strb.toString();
    }
    
    /** 通过小数，获取小数精度 */
    public static int precision(String val)
    {
        Asserts.as(Validates.isFloat(val)?null:"参数都必须是整数或小数");
        
        return new BigDecimal(val).scale();
    }
    
    /** 计算金额，四舍五入 */
    public static String price(String amount, String quantity, int radixLen)
    {
        BigDecimal a = new BigDecimal(amount);
        BigDecimal q = new BigDecimal(quantity);
        
        return a.divide(q, radixLen, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString();
    }
}
